@@ -31,7 +31,7 @@ public:
 
 	void clear();
 
-	explicit operator bool() const { return v_ != 0; };
+	explicit operator bool() const { return v_ != nullptr; };
 
 	T& operator*() { return *v_; }
 	T const& operator*() const { return *v_; }
@@ -75,7 +75,7 @@ sparse_optional<T>::sparse_optional(sparse_optional<T> const& v)
 		v_ = new T(*v);
 	}
 	else {
-		v_ = 0;
+		v_ = nullptr;
 	}
 }
 
@@ -83,7 +83,7 @@ template<typename T>
 sparse_optional<T>::sparse_optional(sparse_optional<T> && v) noexcept
 {
 	v_ = v.v_;
-	v.v_ = 0;
+	v.v_ = nullptr;
 }
 
 template<typename T>
@@ -96,20 +96,19 @@ template<typename T>
 void sparse_optional<T>::clear()
 {
 	delete v_;
-	v_ = 0;
+	v_ = nullptr;
 }
 
 template<typename T>
 sparse_optional<T>& sparse_optional<T>::operator=(sparse_optional<T> const& v)
 {
 	if (this != &v) {
-		delete v_;
+		T* value{};
 		if (v.v_) {
-			v_ = new T(*v.v_);
-		}
-		else {
-			v_ = 0;
+			value = new T(*v.v_);
 		}
+		delete v_;
+		v_ = value;
 	}
 
 	return *this;
@@ -121,7 +120,7 @@ sparse_optional<T>& sparse_optional<T>::operator=(sparse_optional<T> && v) noexc
 	if (this != &v) {
 		delete v_;
 		v_ = v.v_;
-		v.v_ = 0;
+		v.v_ = nullptr;
 	}
 
 	return *this;
@@ -145,7 +144,7 @@ template<typename T>
 bool sparse_optional<T>::operator<(sparse_optional<T> const& cmp) const
 {
 	if (!v_ || !cmp.v_) {
-		return cmp.v_ != 0;
+		return cmp.v_ != nullptr;
 	}
 
 	return *v_ < *cmp.v_;
