@@ -14,28 +14,28 @@
 #define NOMINMAX
 #endif
 
-// IE 7 or higher
+// IE 9 or higher
 #ifndef _WIN32_IE
-#define _WIN32_IE 0x0700
-#elif _WIN32_IE <= 0x0700
+#define _WIN32_IE 0x0900
+#elif _WIN32_IE <= 0x0900
 #undef _WIN32_IE
-#define _WIN32_IE 0x0700
+#define _WIN32_IE 0x0900
 #endif
 
-// Windows Vista or higher
+// Windows 7 or higher
 #ifndef _WIN32_WINNT
-#define _WIN32_WINNT 0x0600
-#elif _WIN32_WINNT < 0x0600
+#define _WIN32_WINNT 0x0601
+#elif _WIN32_WINNT < 0x0601
 #undef _WIN32_WINNT
-#define _WIN32_WINNT 0x0600
+#define _WIN32_WINNT 0x0601
 #endif
 
-// Windows Vista or higher
+// Windows 7 or higher
 #ifndef WINVER
-#define WINVER 0x0600
-#elif WINVER < 0x0600
+#define WINVER 0x0601
+#elif WINVER < 0x0601
 #undef WINVER
-#define WINVER 0x0600
+#define WINVER 0x0601
 #endif
 
 #ifndef _UNICODE
@@ -46,6 +46,10 @@
 #define UNICODE
 #endif
 
+#ifndef STRICT
+#define STRICT 1
+#endif
+
 #include <windows.h>
 #include <shellapi.h>
 
