@@ -1,3 +1,4 @@
+#include "libfilezilla/buffer.hpp"
 #include "libfilezilla/string.hpp"
 
 #ifdef FZ_WINDOWS
@@ -283,9 +284,14 @@ public:
 }
 #endif
 
-std::wstring to_wstring_from_utf8(std::string const& in)
+std::wstring to_wstring_from_utf8(std::string_view const& in)
 {
-	return to_wstring_from_utf8(in.c_str(), in.size());
+	return to_wstring_from_utf8(in.data(), in.size());
+}
+
+std::wstring to_wstring_from_utf8(fz::buffer const& in)
+{
+	return to_wstring_from_utf8(reinterpret_cast<char const*>(in.get()), in.size());
 }
 
 std::wstring to_wstring_from_utf8(char const* s, size_t len)
@@ -428,8 +434,8 @@ std::string FZ_PUBLIC_SYMBOL to_utf8(std::wstring_view const& in)
 }
 
 namespace {
-template<typename String>
-inline bool do_replace_substrings(String& in, String const& find, String const& replacement)
+template<typename String, typename View>
+inline bool do_replace_substrings(String& in, View const& find, View const& replacement)
 {
 	bool ret = false;
 	size_t pos = in.find(find);
@@ -442,30 +448,56 @@ inline bool do_replace_substrings(String& in, String const& find, String const&
 }
 }
 
-std::string replaced_substrings(std::string const& in, std::string const& find, std::string const& replacement)
+std::string replaced_substrings(std::string const& in, std::string_view const& find, std::string_view const& replacement)
 {
 	std::string ret = in;
 	do_replace_substrings(ret, find, replacement);
 	return ret;
 }
 
-std::wstring replaced_substrings(std::wstring const& in, std::wstring const& find, std::wstring const& replacement)
+std::wstring replaced_substrings(std::wstring const& in, std::wstring_view const& find, std::wstring_view const& replacement)
 {
 	std::wstring ret = in;
 	do_replace_substrings(ret, find, replacement);
 	return ret;
 }
 
-bool replace_substrings(std::string& in, std::string const& find, std::string const& replacement)
+std::string replace_substrings(std::string const& in, char find, char replacement)
+{
+	std::string ret = in;
+	do_replace_substrings(ret, std::string_view(&find, 1), std::string_view(&replacement, 1));
+	return ret;
+}
+
+std::wstring replace_substrings(std::wstring const& in, wchar_t find, wchar_t replacement)
+{
+	std::wstring ret = in;
+	do_replace_substrings(ret, std::wstring_view(&find, 1), std::wstring_view(&replacement, 1));
+	return ret;
+}
+
+
+bool replace_substrings(std::string& in, std::string_view const& find, std::string_view const& replacement)
 {
 	return do_replace_substrings(in, find, replacement);
 }
 
-bool replace_substrings(std::wstring& in, std::wstring const& find, std::wstring const& replacement)
+bool replace_substrings(std::wstring& in, std::wstring_view const& find, std::wstring_view const& replacement)
 {
 	return do_replace_substrings(in, find, replacement);
 }
 
+bool replace_substrings(std::string& in, char find, char replacement)
+{
+	return do_replace_substrings(in, std::string_view(&find, 1), std::string_view(&replacement, 1));
+}
+
+bool replace_substrings(std::wstring& in, wchar_t find, wchar_t replacement)
+{
+	return do_replace_substrings(in, std::wstring_view(&find, 1), std::wstring_view(&replacement, 1));
+}
+
+
 namespace {
 template<typename Ret, typename String>
 std::vector<Ret> strtok_impl(String && s, String && delims, bool const ignore_empty)
