@@ -7,6 +7,8 @@
 #include <time.h>
 #include <string.h>
 
+#include <nettle/memops.h>
+
 #if defined(FZ_WINDOWS) && !defined(_MSC_VER)
 #include "libfilezilla/private/windows.hpp"
 #include <wincrypt.h>
@@ -147,4 +149,17 @@ uint64_t bitscan_reverse(uint64_t v)
 #endif
 }
 
+bool equal_consttime(std::basic_string_view<uint8_t> const& lhs, std::basic_string_view<uint8_t> const& rhs)
+{
+	if (lhs.size() != rhs.size()) {
+		return false;
+	}
+
+	if (lhs.empty()) {
+		return true;
+	}
+
+	return nettle_memeql_sec(lhs.data(), rhs.data(), lhs.size()) != 0;
+}
+
 }
