@@ -117,4 +117,9 @@ void format_test::test_sprintf()
 
 	CPPUNIT_ASSERT_EQUAL(std::string("x"), fz::sprintf("%c", char('x')));
 	CPPUNIT_ASSERT_EQUAL(std::string("x"), fz::sprintf("%c", int('x')));
+
+	CPPUNIT_ASSERT_EQUAL(std::string("x"), fz::sprintf("%s", std::string_view("x", 1)));
+	CPPUNIT_ASSERT_EQUAL(std::string("x"), fz::sprintf("%s", std::wstring_view(L"x", 1)));
+	//CPPUNIT_ASSERT_EQUAL(std::wstring(L"x"), fz::sprintf(L"%s", std::string_view("x", 1)));
+	//CPPUNIT_ASSERT_EQUAL(std::wstring(L"x"), fz::sprintf(L"%s", std::wstring_view(L"x", 1)));
 }
